@@ -4,5 +4,5 @@ test_that("findLocation finds hosts and parasite by location", {
   skip_on_cran()
 	expect_error(findLocation("utopia"))
 	France <- findLocation("France")
-	expect_more_than(nrow(France), 2)
+	expect_gt(nrow(France), 2)
 })
